==> bear_utils-0.7.21-py3-none-any.whl: bear_utils/logging/logger_manager/loggers/_buffer_logger.py <==
from logging import DEBUG
from typing import Any, override

from rich.theme import Theme

from ._console_logger import ConsoleLogger
from ._sub_logger import SubConsoleLogger


class BufferLogger(ConsoleLogger):
    """
    A buffer-based logger that writes styled log messages to a buffer.

    Combines Python's logging framework with Rich console styling, but outputs
    to a buffer instead of console or file. Supports buffering of log messages,

    Features:
    - Buffering of log messages
    - Rich-style method generation (info, error, debug, etc.)
    - Consistent print() interface
    - Exception tracebacks in buffer format

    Example:
        logger = BufferLogger.get_instance(
            init=True,
            name="BufferLogger",
        )
        logger.info("This goes to the buffer")
        logger.error("This error is logged to buffer")
    """

    def __init__(
        self,
        theme: Theme | None = None,
        name: str = "BufferLogger",
        level: int = DEBUG,
        *args,
        **kwargs,
    ) -> None:
        ConsoleLogger.__init__(
            self,
            name=name,
            level=level,
            file=False,
            console=False,
            buffering=True,
            queue_handler=kwargs.pop("queue_handler", False),
            theme=theme,
            logger_mode=True,
            **kwargs,
        )

    @override
    def get_sub_logger(self, namespace: str, **kwargs: Any) -> SubConsoleLogger:
        return SubConsoleLogger(self, namespace, **kwargs)

==> bear_utils-0.7.24-py3-none-any.whl: bear_utils/logging/logger_manager/loggers/_buffer_logger.py <==
from logging import DEBUG
from typing import Any, override

from rich.theme import Theme

from ._console_logger import ConsoleLogger
from ._sub_logger import SubConsoleLogger


class BufferLogger(ConsoleLogger):
    """A buffer-based logger that writes styled log messages to a buffer.

    Combines Python's logging framework with Rich console styling, but outputs
    to a buffer instead of console or file. Supports buffering of log messages,

    Features:
    - Buffering of log messages
    - Rich-style method generation (info, error, debug, etc.)
    - Consistent print() interface
    - Exception tracebacks in buffer format

    Example:
        logger = BufferLogger.get_instance(
            init=True,
            name="BufferLogger",
        )
        logger.info("This goes to the buffer")
        logger.error("This error is logged to buffer")
    """

    def __init__(
        self,
        theme: Theme | None = None,
        name: str = "BufferLogger",
        level: int = DEBUG,
        *_,
        **kwargs,
    ) -> None:
        ConsoleLogger.__init__(
            self,
            name=name,
            level=level,
            file=False,
            console=False,
            buffering=True,
            queue_handler=kwargs.pop("queue_handler", False),
            theme=theme,
            logger_mode=True,
            **kwargs,
        )

    @override
    def get_sub_logger(self, namespace: str, **kwargs: Any) -> SubConsoleLogger:
        return SubConsoleLogger(self, namespace, **kwargs)
